OC.L10N.register(
    "files_sharing",
    {
    "Cancel" : "Odustani",
    "Share" : "Dijeli",
    "Pending" : "Na čekanju",
    "Shared by" : "Dijeli",
    "Sharing" : "Dijeljenje",
    "Password" : "Lozinka",
    "Name" : "Ime",
    "Expiration date" : "Datum isteka",
    "Download" : "Preuzmite"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
